<?php

namespace Ems\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\{ Error, Message };
use Ems\Util\ExpectedException;

use Ems\Services\AdmissaoService;

class AdmissaoController {
    /** @var AdmissaoService */
    protected $admissaoService;

    public function __construct(
        AdmissaoService $admissaoService
    ) {
        $this->admissaoService = $admissaoService;
    }

    public function getVinculosNaoAprovados(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $row = $request->getRow();

            $cdOperador = (string) $row['CDOPERADOR'];

            $nrEstrutura = isset($row['NRESTRUTURAM']) ?
                (int) $row['NRESTRUTURAM'] :
                null;

            $admissoes = $this->admissaoService->getVinculosNaoAprovados(
                $cdOperador, $nrEstrutura
            );

            $response->addDataSet(new DataSet('getVinculosNaoAprovados', $admissoes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function setAdmissaoSimplificada(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $row = (array) $request->getRow()->getArrayCopy();

            $success = $this->admissaoService->setAdmissaoSimplificada(
                $row
            );

            $dataset = [
                'success' => $success,
            ];

            $response->addDataSet(new DataSet('setAdmissaoSimplificada', $dataset));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function setAdmissaoCompleta(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $row = (array) $request->getRow()->getArrayCopy();

            $this->admissaoService->setAdmissaoCompleta(
                $row
            );

            $dataset = [
                'success' => true,
            ];

            $response->addDataSet(new DataSet('setAdmissaoCompleta', $dataset));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getTipoFormacaoParc(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $tiposFormacao = $this->admissaoService->getTipoFormacaoParc();

            $response->addDataSet(new DataSet('getTipoFormacaoParc', $tiposFormacao));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getCursoAcademico(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $cursos = $this->admissaoService->getCursoAcademico();

            $response->addDataSet(new DataSet('getCursoAcademico', $cursos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getInstituicaoEstrutura(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $instituicoes = $this->admissaoService->getInstituicaoEstrutura();

            $response->addDataSet(new DataSet('getInstituicaoEstrutura', $instituicoes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getAreaFormacao(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $areas = $this->admissaoService->getAreaFormacao();

            $response->addDataSet(new DataSet('getAreaFormacao', $areas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getBeneficio(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $beneficios = $this->admissaoService->getBeneficio();

            $response->addDataSet(new DataSet('getBeneficio', $beneficios));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getTipoVinculo(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $tipos = $this->admissaoService->getTipoVinculo();

            $response->addDataSet(new DataSet('getTipoVinculo', $tipos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getTipoAdmissao(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $tipos = $this->admissaoService->getTipoAdmissao();

            $response->addDataSet(new DataSet('getTipoAdmissao', $tipos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getVinculoEmpregaticio(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $vinculosEmp = $this->admissaoService->getVinculoEmpregaticio();

            $response->addDataSet(new DataSet('getVinculoEmpregaticio', $vinculosEmp));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getTipoOcupacao(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $tipos = $this->admissaoService->getTipoOcupacao();

            $response->addDataSet(new DataSet('getTipoOcupacao', $tipos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getOcupacao(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $ocupacoes = $this->admissaoService->getOcupacao();

            $response->addDataSet(new DataSet('getOcupacao', $ocupacoes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getEstruturaGerLeg(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $estruturas = $this->admissaoService->getEstruturaGerLeg();

            $response->addDataSet(new DataSet('getEstruturaGerLeg', $estruturas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getEstruturaLegal(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $estruturas = $this->admissaoService->getEstruturaLegal();

            $response->addDataSet(new DataSet('getEstruturaLegal', $estruturas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getTipoSalario(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $tipos = $this->admissaoService->getTipoSalario();

            $response->addDataSet(new DataSet('getTipoSalario', $tipos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}
