<?php

namespace Ems\Controllers;

use Exception\Messages;
use Service\LogService;
use Service\OAuth\OAuthCustomImpl;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\HTTP\Kernel;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO;


use Ems\Services\AlteSalarioService;

class AlteSalarioController {

    /** @var OcorrenciaService */
    protected $alteSalarioService;
    
    public function __construct(EntityManager $entityManager, AlteSalarioService $alteSalarioService) {
        $this->entityManager        = $entityManager;
        $this->alteSalarioService   = $alteSalarioService;
    }
    
    public function getModalidadeSalarial(Request\Row $request, Response $response) {
        try {

            $dados = $this->alteSalarioService->getModalidadeSalarial();

            $response->addDataSet(new DataSet('getModalidadeSalarial', $dados));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getTipoAlteraSal(Request\Row $request, Response $response) {
        try {

            $dados = $this->alteSalarioService->getTipoAlteraSal();

            $response->addDataSet(new DataSet('getTipoAlteraSal', $dados));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    public function getUltimoSalario(Request\Row $request, Response $response) {
        try {
            $params = $request->getRow();
            $nrvinculom = $params['NRVINCULOM'];
            
            $dados = $this->alteSalarioService->getUltimoSalario($nrvinculom);

            $response->addDataSet(new DataSet('getUltimoSalario', $dados));

        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

}
